C----------------------------------------------------------------------
      SUBROUTINE BOUND
C       Calculate potential depth or binding energy and 
C       BOUND STATE WAVE FUNCTIONS:  CI(NR,(SP.NO1,SP.NO2))
C       Modified by M.Ichimura 2017.9.16
C----------------------------------------------------------------------
C  INDEX
C    ICH=1: neutron, ICH=2:proton
C    NSPZ : Single particle level number
C    NR   : Mesh point number of r
C  INPUT
C    IA=1:Calculate the potential depth for the given binding energy
C      =2 Calculate the binding energy for the given potential depth
C          and no spreading width
C    KTHSPWD =0: no spreading width
C            =1: with spreading width of holes
C  OUTPUT
C    VD(ICH): Potential depth for neutron(ICH=1) and proton(ICH=2)
C    BERSPD(NSPZ,ICH): Real part of the binding energy
C    BEISPD(NSPZ,ICH): Imaginary part of the binding energy 
C    CICX(NR,NSP1Z):Bound state wave function
C---------------------------------------------------------------------
      INCLUDE 'dimn.fh'
      INCLUDE 'fund1.fh'
      INCLUDE 'opta1.fh'
      INCLUDE 'orbt.fh'
      INCLUDE 'wave.fh'
C
      COMPLEX VDEPTH,BENGY,WI0,FFCX
      DIMENSION RPUT(18),IPUT(4),FFCX(402)
      PARAMETER(WI0=(0.0,1.0))
C
C   DO LOOP FOR ICH=1:NEUTRON, 2:PROTON
      DO 160 ICH=1,2
        DO NSPZ=1,NSPMX(ICH)
           BEISPD(NSPZ,ICH)=0.0 
        END DO
C   SET IA
        IF(ABS(VD(ICH)).GT.0.1) THEN
          IA=2
        ELSE
          IA=1
        END IF
C
C     SET INPUT DATA(RPUT,VDEPTH) FOR CXBD1
        VDEPTH=CMPLX(VD(ICH))
        NRAMAX=NRMAX
        DRX=DR
        RPUT(1)=PMAS(ICH)
        RPUT(2)=TMAS(ICH)
        RPUT(3)=RRD(ICH)
        RPUT(4)=ARD(ICH)
        RPUT(5)=WV0(ICH)
        RPUT(6)=WS0(ICH)
        RPUT(7)=RVD2(ICH)
        RPUT(8)=AVD2(ICH)
        RPUT(9)=RID(ICH)
        RPUT(10)=AID(ICH)
        RPUT(11)=VSOD(ICH)
        RPUT(12)=RSOD(ICH)
        RPUT(13)=ASOD(ICH)
        RPUT(14)=PZTZ(ICH)
        RPUT(15)=REFFD(ICH)
        RPUT(16)=AEFFD(ICH)
        RPUT(17)=BDIFD(ICH)
        RPUT(18)=rcd(ich)
C
C     DO LOOP FOR SINGLE PARTICLE STATES
        DO 140 NSPZ=1,NSPMX(ICH)
C
C       SET INPUT DATA(N,L,S,J,BENGY) FOR CXBD1
          IPUT(4)=NSPD(NSPZ,ICH)
          IPUT(1)=LSPD(NSPZ,ICH)
          IPUT(3)=2*FJSPD(NSPZ,ICH)+0.01
          IPUT(2)=2*PSPN(ICH)+0.01
          BENGY=CMPLX(BERSPD(NSPZ,ICH))
C----------------------------------------------------------------------
          CALL CXBD1(IA,DRX,NRAMAX,IPUT,BENGY,VDEPTH,RPUT,FFCX)
C----------------------------------------------------------------------
C       SET VD(ICH) OR BERSPD(ICH) FROM CXBD1
          IF(IA.EQ.1) THEN
             IA=2
             VD(ICH)=REAL(VDEPTH)
             ICH2=ICH+2
             IF(ABS(VD(ICH2)).LT.0.001) THEN
                VD(ICH2)=VD(ICH)
             END IF
          ELSE
            BERSPD(NSPZ,ICH)=REAL(BENGY)
          END IF
C
C       WOODS-SAXSON BOUND STATE WAVE FUNC.
          NSP1Z=NSPZ+NSPMX(1)*(ICH-1)
            DO 130 NR=1,NRMAX
            CICX(NR,NSP1Z)=FFCX(NR)
  130       CONTINUE
         IF(KTHSPWD.EQ.1) THEN
         BEISPD(NSPZ,ICH)=SPWD(-BERSPD(NSPZ,ICH),BEFM(ICH),
     &                         alphsw(ich),eps0sw(ich),eps1sw(ich))
         END IF
  140   CONTINUE
  160 CONTINUE
C
      RETURN
      END
