C-----------------------------------------------------------------
      subroutine drcopt(ICH,nrmax,fkay1,Atg,zzz,rhobc1,drho1)
C       Generate Schroedinger equivalent optical potential from 
C       Dirac phenomenologocal optical potential
C-----------------------------------------------------------------
C  INPUT from argument
C    ich    : =1: incident channel =2: exit channel 
C    nrmax  : Maximum no. of radial mesh points 
C    fkay1  : k in c.m
C    Atg    : A_{tg}
C    zzz    : Z_{prj}*Z_{tg} for ich=1;  Z_{ejc}*Z_{rs} for ich=2
C    rhobc1 : k*R_{tg}
C    drho1  : k*dr
C  INPUT from common/drcpot/
C    vsd(ich) :V_s Scalar pot.(real)
C    wsd(ich) :W_s Scalar pot.(imaginary)
C    rsd(ich) :r_{sr} radius parameter of Scalar pot.(real)
C    asd(ich) :a_{sr} diffuseness parameter of Scalar pot.(real)
C    rsid(ich):r_{si} radius parameter of Scalar pot.(imaginary)
C    asid(ich):a_{si} diffuseness parameter of Scalar pot.(imaginary)
C    vvd(ich) :V_v Vector pot.(real)
C    wvd(ich) :W_v Vector pot.(imaginary)
C    rvd(ich) :r_{vr} radius parameter of vector pot.(real)
C    avd(ich) :a_{vr} diffuseness parameter of vector pot.(real)
C    rvid(ich):r_{vi} radius parameter of vector pot.(imaginary)
C    avid(ich):a_{vi} diffuseness parameter of vector pot.(imaginary)
C  OUTPUT to common/modpot/
c    (vbcd1(nr,ich),wbcd1(nr,ich)) = (1.0 - U_{cent}/E)
c    (vsov1(nr,ich),wsov(nr,ich))  = -U_{so}/E
c    bdrc(nr,ich) :Darwin factor
C=================================================================
      include 'dimn.fh'
      include 'drcpot.fh'
      include 'modpot.fh'
c
      complex us,ueff,uvvc,bbb,uso,udw1,ud1,udw
c constants
      real*8 hc/197.326968d0/
      REAL*8 MN_AV/938.91937d0/
      REAL*8 al/137.036d0/
c
        t2=fkay1*Atg**0.3333333
        rhobc2=rhobc1*rhobc1
        rhobc3=rhobc2*rhobc1
        rhos =t2*rsd(ich)
        rhosi=t2*rsid(ich)
        rhov =t2*rvd(ich)
        rhovi=t2*rvid(ich)
        fkayas=fkay1*asd(ich)
        fkaasi=fkay1*asid(ich)
        fkayav=fkay1*avd(ich)
        fkaavi=fkay1*avid(ich)
        hck=hc*fkay1
        edrc=sqrt(MN_AV**2+hck**2)
        f1=MN_AV/edrc
        f2=0.5/edrc
        vce=zzz*hck/al
        vsdw=vsd(ich)/fkayas
        wsdw=wsd(ich)/fkaasi
        vvdw=vvd(ich)/fkayav
        wvdw=wvd(ich)/fkaavi
        rho=drho1
        do 500 nr=1,nrmax+3
          rho2=rho*rho
          rho1=1.0/rho
          xs=(rho-rhos)/fkayas
          xsi=(rho-rhosi)/fkaasi
          xv=(rho-rhov)/fkayav
          xvi=(rho-rhovi)/fkaavi
          exs =exp(xs)
          exsi=exp(xsi)
          exv =exp(xv)
          exvi=exp(xvi)
          ss1  =1.0/(1.0+exs)
          ssdw1=exs*ss1
          ssdw2=ssdw1*ss1
          ssi1  =1.0/(1.0+exsi)
          ssdwi1=exsi*ssi1
          ssdwi2=ssdwi1*ssi1
          sv1  =1.0/(1.0+exv)
          svdw1=exv*sv1
          svdw2=svdw1*sv1
          svi1  =1.0/(1.0+exvi)
          svdwi1=exvi*svi1
          svdwi2=svdwi1*svi1
          if(zzz.ge.1.0) then
            if(rho.gt.rhobc1) then
              vc =vce/rho
              vc2=vc/rho
              vc3=0.
            else
              vc =0.5*vce*(3.-rho*rho/rhobc2)/rhobc1
              vc2=vce*rho/rhobc3
              vc3=1.5*vce/rhobc3
            end if
          else
            vc =0.
            vc2=0.
            vc3=0.
          end if
          uvvc=cmplx(vvd(ich)*sv1+vc,wvd(ich)*svi1)
          us  =cmplx(vsd(ich)*ss1,wsd(ich)*ssi1)
          bbb=us-uvvc+edrc+MN_AV
c  drw*drw*drw*drw
          addr=vsdw*ssdw2*(rho1+0.5/fkayas-ssdw1/fkayas)
     1        -vvdw*svdw2*(rho1+0.5/fkayav-svdw1/fkayav)+vc3
          addi=wsdw*ssdwi2*(rho1+0.5/fkaasi-ssdwi1/fkaasi)
     1        -wvdw*svdwi2*(rho1+0.5/fkaavi-svdwi1/fkaavi)
          udw1=cmplx(addr,addi)/bbb
          adr =-vsdw*ssdw2+vvdw*svdw2+vc2
          adi =-wsdw*ssdwi2+wvdw*svdwi2
          ud1 =cmplx(adr,adi)/bbb
          udw =udw1+(3.0/4.0)*ud1**2
          ueff= 2.*edrc/hck**2*(uvvc+f1*us+f2*(us*us-uvvc*uvvc))+udw
          vbcd1(nr,ich)=1.0-real(ueff)
          wbcd1(nr,ich)=-aimag(ueff)
c  so*so*so*so
          uso=-2.0/rho*ud1
          vsov1(nr,ich)= -real(uso)
          wsov(nr,ich) =-aimag(uso)
          rho=rho+drho1
c b*b*b
          bdrc(nr,ich)= sqrt(bbb/(edrc+MN_AV))
  500   continue
c
        return
        end
