C***********************************************************************
      SUBROUTINE NNAMP_FL(Q,ENERGY,MASNUM,TAMPFL)
C     NN-AMPLITUDE
C     FRANEY & LOVE   Phys.Rev.C31,488(1985)
C
C     INPUT DATA
C       Q    : MOMENTUM TRANSFER IN C.M.FRAME
C      ENERGY: INCIDENT ENERGY IN LAB. FRAME
C
C     VARIABLES
C       VSOD : SINGLET ODD DIRECT
C       VTOD : TRIPLET ODD DIRECT
C       VSED : SINGLET EVEN DIRECT
C       VTED : TRIPLET EVEN DIRECT
C       VSOE : SINGLET ODD EXCHANGE
C       VTOE : TRIPLET ODD EXCHANGE
C       VSEE : SINGLET EVEN EXCHANGE
C       VTEE : TRIPLET EVEN EXCHANGE
C
C       VLSOD : LS ODD DIRECT
C       VLSED : LS EVEN DIRECT
C       VLSOE : LS ODD EXCHANGE
C       VLSED : LS EVEN EXCHANGE
C
C       VTNOD : TENSOR ODD DIRECT
C       VTNED : TENSOR EVEN DIRECT
C       VTNOE : TENSOR ODD EXCHANGE
C       VTNEE : TENSOR EVEN EXCHANGE
C
C     RESULTS IN TAMP(1,I) I=19-28
C       CHANNEL19 : ETA*ALPHA0
C              20 : ETA*ALPHA1
C              21 : ETA*BETA0
C              22 : ETA*BETA1
C              23 : ETA*GAMMA0
C              24 : ETA*GAMMA
C              25 : ETA*DELTA0
C              26 : ETA*DELTA1
C              27 : ETA*EPSILON0
C              28 : ETA*EPSILON1
C***********************************************************************
      DIMENSION ENGY(13)
      DIMENSION FNL(13)
      DIMENSION NUMDAT(13),NUMDT2(13)
      DIMENSION RANGE(10,13),RANGE2(10,13)
C
      COMPLEX VCSO(10,13),VSOD(0:13),VSOE(0:13)
      COMPLEX VCTO(10,13),VTOD(0:13),VTOE(0:13)
      COMPLEX VCSE(10,13),VSED(0:13),VSEE(0:13)
      COMPLEX VCTE(10,13),VTED(0:13),VTEE(0:13)
C
      COMPLEX VLSO(10,13),VLSOD(0:13),VLSOE(0:13)
      COMPLEX VTNO(10,13),VTNOD(0:13),VTNOE(0:13)
      COMPLEX VLSE(10,13),VLSED(0:13),VLSEE(0:13)
      COMPLEX VTNE(10,13),VTNED(0:13),VTNEE(0:13)
C
      COMPLEX TAMPFL(10)
C
      real*8 hc/197.326968d0/
      real*8 cpi/3.141592654d0/
C
      PARAMETER(PROTMS=938.272)
      PARAMETER(UNITMS=938.272)
C     
C KINEMATICS
      PP=SQRT(ENERGY*(ENERGY+2.0*PROTMS))
      EP=PROTMS+ENERGY
      BETACM=PP/(EP+UNITMS)
      GAMMCM=1.0/SQRT(1.0-BETACM*BETACM)
      P1=BETACM*GAMMCM*UNITMS
      FK1=P1/HC
      FK=FK1
C
C KINEMATIC MODIFICATION FOR CALCULATING NUCLEON-NUCLEUS SCATTERING
      ALPHA=ENERGY/(2.0*PROTMS)
      BETA=4.0*ALPHA*MASNUM/((MASNUM+1)**2)
      P1NASQ=PROTMS*PROTMS*MASNUM*BETA*((1.0+ALPHA)/(1.0+BETA))
      QQ=SQRT(P1NASQ)/HC
      E1SQ=PROTMS*PROTMS*(1.0+ALPHA)
      E1NASQ=PROTMS*PROTMS+P1NASQ
      E2NASQ=PROTMS*PROTMS+P1NASQ/(MASNUM*MASNUM)
      FACMOD=E1SQ/SQRT(E1NASQ*E2NASQ)
C
C DATA POINTS
      ENGY(1)=50.0
      ENGY(2)=100.0
      ENGY(3)=140.0
      ENGY(4)=175.0
      ENGY(5)=210.0
      ENGY(6)=270.0
      ENGY(7)=325.0
      ENGY(8)=425.0
      ENGY(9)=515.0
      ENGY(10)=650.0
      ENGY(11)=725.0
      ENGY(12)=800.0
      ENGY(13)=1000.0
C
      DO 30 NENGMX=2,13
        IF (ENERGY.LE.ENGY(NENGMX))GOTO 40
 30   CONTINUE
 40   CONTINUE
      NENGMN=NENGMX-1
C
C LAGRANGE INTERPOLATION
C FUNCTION L_J^(NUMENG-1)(ENERGY)
      DO 90 J=NENGMN,NENGMX
        FNUM=1.0
        DENOM=1.0
        DO 50 I=NENGMN,J-1
          FNUM=FNUM*(ENERGY-ENGY(I))
          DENOM=DENOM*(ENGY(J)-ENGY(I))
   50   CONTINUE
        DO 80 I=J+1,NENGMX
          FNUM=FNUM*(ENERGY-ENGY(I))
          DENOM=DENOM*(ENGY(J)-ENGY(I))
   80   CONTINUE
        FNL(J)=FNUM/DENOM
C        WRITE(*,*)'FNL(',J,')=',FNL(J)
   90 CONTINUE
C
C**************
C SINGLET ODD *
C**************
C
C 50 MeV DATA
      NUMDAT(1)=3
C
      RANGE(1,1)=0.25
      RANGE(2,1)=0.40
      RANGE(3,1)=1.40
C
      VCSO(1,1)=(-1.13818E+05, 1.74344E+04)
      VCSO(2,1)=( 1.23150E+04,-2.27828E+03)
      VCSO(3,1)=( 3.15000E+01, 0.0)
C
C 100 MeV DATA
      NUMDAT(2)=3
C
      RANGE(1,2)=0.25
      RANGE(2,2)=0.40
      RANGE(3,2)=1.40
C
      VCSO(1,2)=(-1.82269E+04, 7.34567E+03)
      VCSO(2,2)=( 2.53674E+03,-1.40826E+03)
      VCSO(3,2)=( 3.15000E+01, 0.0)
C
C 140 MeV DATA
      NUMDAT(3)=3
C
      RANGE(1,3)=0.25
      RANGE(2,3)=0.40
      RANGE(3,3)=1.40
C
      VCSO(1,3)=(-2.54198E+03, 2.87199E+03)
      VCSO(2,3)=( 7.82429E+02,-9.83301E+02)
      VCSO(3,3)=( 3.15000E+01, 0.0)
C
C 175 MeV DATA
      NUMDAT(4)=3
C
      RANGE(1,4)=0.25
      RANGE(2,4)=0.40
      RANGE(3,4)=1.40
C
      VCSO(1,4)=( 2.57057E+03, 5.38800E+02)
      VCSO(2,4)=( 1.31554E+02,-7.37824E+02)
      VCSO(3,4)=( 3.15000E+01, 0.0)
C
C 210 MeV DATA
      NUMDAT(5)=3
C
      RANGE(1,5)=0.25
      RANGE(2,5)=0.40
      RANGE(3,5)=1.40
C
      VCSO(1,5)=( 4.71412E+03,-9.19824E+02)
      VCSO(2,5)=(-1.93752E+02,-5.63008E+02)
      VCSO(3,5)=( 3.15000E+01, 0.0)
C
C 270 MeV DATA
      NUMDAT(6)=4
C
      RANGE(1,6)=0.25
      RANGE(2,6)=0.40
      RANGE(3,6)=0.55
      RANGE(4,6)=1.40
C
      VCSO(1,6)=(-5.15172E+04,-2.20625E+03)
      VCSO(2,6)=( 1.67780E+04,-3.51375E+02)
      VCSO(3,6)=(-2.59918E+03,-6.27354E+00)
      VCSO(4,6)=( 3.15000E+01, 0.0)
C
C 325 MeV DATA
      NUMDAT(7)=4
C
      RANGE(1,7)=0.25
      RANGE(2,7)=0.40
      RANGE(3,7)=0.55
      RANGE(4,7)=1.40
C
      VCSO(1,7)=(-2.90946E+04,-3.42869E+03)
      VCSO(2,7)=( 1.08510E+04,-3.92545E+01)
      VCSO(3,7)=(-1.83954E+03,-3.31254E+01)
      VCSO(4,7)=( 3.15000E+01, 0.0)
C
C 425 MeV DATA
      NUMDAT(8)=4
C
      RANGE(1,8)=0.25
      RANGE(2,8)=0.40
      RANGE(3,8)=0.55
      RANGE(4,8)=1.40
C
      VCSO(1,8)=(-1.07026E+04,-4.19302E+03)
      VCSO(2,8)=( 5.12368E+03, 3.12140E+02)
      VCSO(3,8)=(-9.72663E+02,-7.69847E+01)
      VCSO(4,8)=( 3.15000E+01, 0.0)
C
C 515 MeV DATA
      NUMDAT(9)=4
C
      RANGE(1,9)=0.25
      RANGE(2,9)=0.40
      RANGE(3,9)=0.55
      RANGE(4,9)=1.40
C
      VCSO(1,9)=(-1.99145E+03,-4.53095E+03)
      VCSO(2,9)=( 1.79298E+03, 6.06959E+02)
      VCSO(3,9)=(-3.71019E+02,-1.28415E+02)
      VCSO(4,9)=( 3.15000E+01, 0.0)
C
C 650 MeV DATA
      NUMDAT(10)=4
C
      RANGE(1,10)=0.15
      RANGE(2,10)=0.25
      RANGE(3,10)=0.40
      RANGE(4,10)=1.40
C
      VCSO(1,10)=( 1.09428E+05,-5.36021E+04)
      VCSO(2,10)=(-2.16072E+04, 9.00582E+03)
      VCSO(3,10)=( 1.70630E+03,-8.67157E+02)
      VCSO(4,10)=( 3.15000E+01, 0.0)
C
C 725 MeV DATA
      NUMDAT(11)=4
C
      RANGE(1,11)=0.15
      RANGE(2,11)=0.25
      RANGE(3,11)=0.40
      RANGE(4,11)=1.40
C
      VCSO(1,11)=( 1.53833E+05,-5.79652E+04)
      VCSO(2,11)=(-3.32664E+04, 1.09094E+04)
      VCSO(3,11)=( 2.75486E+03,-1.05559E+03)
      VCSO(4,11)=( 3.15000E+01, 0.0)
C
C 800 MeV DATA
      NUMDAT(12)=4
C
      RANGE(1,12)=0.15
      RANGE(2,12)=0.25
      RANGE(3,12)=0.40
      RANGE(4,12)=1.40
C
      VCSO(1,12)=( 1.74821E+05,-6.18452E+04)
      VCSO(2,12)=(-4.02615E+04, 1.27774E+04)
      VCSO(3,12)=( 3.51229E+03,-1.26088E+03)
      VCSO(4,12)=( 3.15000E+01, 0.0)
C
C 1000 MeV DATA
      NUMDAT(13)=4
C
      RANGE(1,13)=0.15
      RANGE(2,13)=0.25
      RANGE(3,13)=0.40
      RANGE(4,13)=1.40
C
      VCSO(1,13)=( 1.77348E+05,-6.87148E+04)
      VCSO(2,13)=(-4.64711E+04, 1.70941E+04)
      VCSO(3,13)=( 4.59027E+03,-1.82287E+03)
      VCSO(4,13)=( 3.15000E+01, 0.0)
C
  100 CONTINUE
C
C DO LOOP OF ENERGY
      DO 150 J=NENGMN,NENGMX
C DIRECT
      VSOD(J)=(0.0,0.0)
      DO 120 I=1,NUMDAT(J)
        VSOD(J)=VSOD(J)+
     &   4.0*CPI*VCSO(I,J)*(RANGE(I,J)**3.0)/(1.0+(Q*RANGE(I,J))**2.0)
  120 CONTINUE
C
C EXCHANGE
      VSOE(J)=(0.0,0.0)
      DO 130 I=1,NUMDAT(J)
        VSOE(J)=VSOE(J)+
     &   4.0*CPI*VCSO(I,J)*(RANGE(I,J)**3.0)/(1.0+(QQ*RANGE(I,J))**2.0)
  130 CONTINUE
  150 CONTINUE
C
C INTERPOLATION
C DIRECT
      VSOD(0)=(0.0,0.0)
      DO 180 J=NENGMN,NENGMX
        VSOD(0)=VSOD(0)+VSOD(J)*FNL(J)
  180 CONTINUE
C
C EXCHANGE
      VSOE(0)=(0.0,0.0)
      DO 190 J=NENGMN,NENGMX
        VSOE(0)=VSOE(0)+VSOE(J)*FNL(J)
  190 CONTINUE
C
C**************
C TRIPLET ODD *
C**************
C
C 50 MeV DATA
      VCTO(1,1)=( 4.64708E+03, 8.98647E+03)
      VCTO(2,1)=(-1.42516E+03,-1.38108E+03)
      VCTO(3,1)=( 3.50000E+00, 0.0)
C
C 100 MeV DATA
      VCTO(1,2)=( 7.69888E+03, 2.41839E+03)
      VCTO(2,2)=(-1.60906E+03,-6.83690E+02)
      VCTO(3,2)=( 3.50000E+00, 0.0)
C
C 140 MeV DATA
      VCTO(1,3)=( 7.86482E+03, 4.68991E+02)
      VCTO(2,3)=(-1.56881E+03,-4.40472E+02)
      VCTO(3,3)=( 3.50000E+00, 0.0)
C
C 175 MeV DATA
      VCTO(1,4)=( 7.64504E+03,-4.65650E+02)
      VCTO(2,4)=(-1.50695E+03,-3.10545E+02)
      VCTO(3,4)=( 3.50000E+00, 0.0)
C
C 210 MeV DATA
      VCTO(1,5)=( 7.31342E+03,-1.07689E+03)
      VCTO(2,5)=(-1.43949E+03,-2.17827E+02)
      VCTO(3,5)=( 3.50000E+00, 0.0)
C
C 270 MeV DATA
      VCTO(1,6)=( 5.80993E+03,-2.86675E+03)
      VCTO(2,6)=(-1.03573E+03, 2.28178E+02)
      VCTO(3,6)=(-5.07069E+01,-5.01090E+01)
      VCTO(4,6)=( 3.50000E+00, 0.0)
C
C 325 MeV DATA
      VCTO(1,7)=( 5.06449E+03,-3.11320E+03)
      VCTO(2,7)=(-8.88719E+02, 2.93804E+02)
      VCTO(3,7)=(-5.56569E+01,-5.32725E+01)
      VCTO(4,7)=( 3.50000E+00, 0.0)
C
C 425 MeV DATA
      VCTO(1,8)=( 4.22421E+03,-3.36721E+03)
      VCTO(2,8)=(-7.42432E+02, 3.80106E+02)
      VCTO(3,8)=(-5.96291E+01,-6.13174E+01)
      VCTO(4,8)=( 3.50000E+00, 0.0)
C
C 515 MeV DATA
      VCTO(1,9)=( 3.85887E+03,-3.02781E+03)
      VCTO(2,9)=(-6.94943E+02, 2.76610E+02)
      VCTO(3,9)=(-5.86496E+01,-5.91977E+01)
      VCTO(4,9)=( 3.50000E+00, 0.0)
C
C 650 MeV DATA
      VCTO(1,10)=(-3.70087E+04,-1.65674E+04)
      VCTO(2,10)=( 1.21868E+04, 3.10462E+03)
      VCTO(3,10)=(-1.51348E+03,-7.97327E+02)
      VCTO(4,10)=( 3.50000E+00, 0.0)
C
C 725 MeV DATA
      VCTO(1,11)=(-7.72934E+04,-2.80378E+02)
      VCTO(2,11)=( 2.06031E+04, 6.91432E+02)
      VCTO(3,11)=(-2.02964E+03,-8.53213E+02)
      VCTO(4,11)=( 3.50000E+00, 0.0)
C
C 800 MeV DATA
      VCTO(1,12)=(-1.09247E+05, 9.23141E+03)
      VCTO(2,12)=( 2.75371E+04,-1.27355E+03)
      VCTO(3,12)=(-2.42834E+03,-7.83507E+02)
      VCTO(4,12)=( 3.50000E+00, 0.0)
C
C 1000 MeV DATA
      VCTO(1,13)=(-1.30837E+05, 8.44559E+03)
      VCTO(2,13)=( 3.36377E+04,-2.02912E+03)
      VCTO(3,13)=(-2.80368E+03,-6.45713E+02)
      VCTO(4,13)=( 3.50000E+00, 0.0)
C
  200 CONTINUE
C
C DO LOOP OF ENERGY
      DO 250 J=NENGMN,NENGMX
C DIRECT
      VTOD(J)=(0.0,0.0)
      DO 220 I=1,NUMDAT(J)
        VTOD(J)=VTOD(J)+
     &   4.0*CPI*VCTO(I,J)*(RANGE(I,J)**3.0)/(1.0+(Q*RANGE(I,J))**2.0)
  220 CONTINUE
C
C EXCHANGE
      VTOE(J)=(0.0,0.0)
      DO 230 I=1,NUMDAT(J)
        VTOE(J)=VTOE(J)+
     &   4.0*CPI*VCTO(I,J)*(RANGE(I,J)**3.0)/(1.0+(QQ*RANGE(I,J))**2.0)
  230 CONTINUE
  250 CONTINUE
C
C INTERPOLATION
C DIRECT
      VTOD(0)=(0.0,0.0)
      DO 280 J=NENGMN,NENGMX
        VTOD(0)=VTOD(0)+VTOD(J)*FNL(J)
  280 CONTINUE
C
C EXCHANGE
      VTOE(0)=(0.0,0.0)
      DO 290 J=NENGMN,NENGMX
        VTOE(0)=VTOE(0)+VTOE(J)*FNL(J)
  290 CONTINUE
C
C***************
C LS ODD       *
C***************
C
C 50 MeV DATA
      NUMDT2(1)=4
C
      RANGE2(1,1)=0.25
      RANGE2(2,1)=0.40
      RANGE2(3,1)=0.55
      RANGE2(4,1)=0.70
C
      VLSO(1,1)=( 4.47808E+03,-3.52978E+03)
      VLSO(2,1)=(-1.30427E+03, 5.64196E+02)
      VLSO(3,1)=( 0.0        , 0.0        )
      VLSO(4,1)=( 0.0        , 0.0        )
C
C 100 MeV DATA
      NUMDT2(2)=4
C
      RANGE2(1,2)=0.25
      RANGE2(2,2)=0.40
      RANGE2(3,2)=0.55
      RANGE2(4,2)=0.70
C
      VLSO(1,2)=(-1.68570E+03,-1.54304E+03)
      VLSO(2,2)=(-6.14658E+02, 2.41376E+02)
      VLSO(3,2)=( 0.0        , 0.0        )
      VLSO(4,2)=( 0.0        , 0.0        )
C
C 140 MeV DATA
      NUMDT2(3)=4
C
      RANGE2(1,3)=0.25
      RANGE2(2,3)=0.40
      RANGE2(3,3)=0.55
      RANGE2(4,3)=0.70
C
      VLSO(1,3)=(-3.09627E+03,-9.73518E+02)
      VLSO(2,3)=(-3.94780E+02, 1.41641E+02)
      VLSO(3,3)=( 0.0        , 0.0        )
      VLSO(4,3)=( 0.0        , 0.0        )
C
C 175 MeV DATA
      NUMDT2(4)=4
C
      RANGE2(1,4)=0.25
      RANGE2(2,4)=0.40
      RANGE2(3,4)=0.55
      RANGE2(4,4)=0.70
C
      VLSO(1,4)=(-3.58318E+03,-6.09087E+02)
      VLSO(2,4)=(-2.88049E+02, 8.99986E+01)
      VLSO(3,4)=( 0.0        , 0.0        )
      VLSO(4,4)=( 0.0        , 0.0        )
C
C 210 MeV DATA
      NUMDT2(5)=4
C
      RANGE2(1,5)=0.15
      RANGE2(2,5)=0.25
      RANGE2(3,5)=0.40
      RANGE2(4,5)=0.70
C
      VLSO(1,5)=( 0.0        , 0.0        )
      VLSO(2,5)=(-3.75475E+03,-2.85062E+02)
      VLSO(3,5)=(-2.23300E+02, 5.25282E+01)
      VLSO(4,5)=( 0.0        , 0.0        )
C
C 270 MeV DATA
      NUMDT2(6)=5
C
      RANGE2(1,6)=0.15
      RANGE2(2,6)=0.25
      RANGE2(3,6)=0.40
      RANGE2(4,6)=0.55
      RANGE2(5,6)=0.70
C
      VLSO(1,6)=( 0.0        , 0.0        )
      VLSO(2,6)=(-3.32120E+03, 4.24916E+02)
      VLSO(3,6)=(-2.94795E+02,-6.12376E+01)
      VLSO(4,6)=( 2.23046E+01, 9.69778E+00)
      VLSO(5,6)=( 0.0        , 0.0        )
C
C 325 MeV DATA
      NUMDT2(7)=5
C
      RANGE2(1,7)=0.15
      RANGE2(2,7)=0.25
      RANGE2(3,7)=0.40
      RANGE2(4,7)=0.55
      RANGE2(5,7)=0.70
C
      VLSO(1,7)=( 0.0        , 0.0        )
      VLSO(2,7)=(-3.27210E+03, 8.86239E+02)
      VLSO(3,7)=(-2.15065E+02,-1.26202E+02)
      VLSO(4,7)=( 1.18946E+01, 1.49179E+01)
      VLSO(5,7)=( 0.0        , 0.0        )
C
C 425 MeV DATA
      NUMDT2(8)=5
C
      RANGE2(1,8)=0.15
      RANGE2(2,8)=0.25
      RANGE2(3,8)=0.40
      RANGE2(4,8)=0.55
      RANGE2(5,8)=0.70
C
      VLSO(1,8)=( 0.0        , 0.0        )
      VLSO(2,8)=(-2.74284E+03, 1.58660E+03)
      VLSO(3,8)=(-2.06220E+02,-2.38814E+02)
      VLSO(4,8)=( 1.14875E+01, 2.67798E+01)
      VLSO(5,8)=( 0.0        , 0.0        )
C
C 515 MeV DATA
      NUMDT2(9)=6
C
      RANGE2(1,9)=0.11
      RANGE2(2,9)=0.15
      RANGE2(3,9)=0.25
      RANGE2(4,9)=0.40
      RANGE2(5,9)=0.55
      RANGE2(6,9)=0.70
C
      VLSO(1,9)=( 0.0        , 0.0        )
      VLSO(2,9)=( 0.0        , 0.0        )
      VLSO(3,9)=(-2.10524E+03, 2.12228E+03)
      VLSO(4,9)=(-2.64773E+02,-3.16013E+02)
      VLSO(5,9)=( 1.98962E+01, 3.65258E+01)
      VLSO(6,9)=( 0.0        , 0.0        )
C
C 650 MeV DATA
      NUMDT2(10)=5
C
      RANGE2(1,10)=0.11
      RANGE2(2,10)=0.15
      RANGE2(3,10)=0.25
      RANGE2(4,10)=0.40
      RANGE2(5,10)=0.70
C
      VLSO(1,10)=( 0.0        , 0.0        )
      VLSO(2,10)=( 1.03698E+04, 9.19289E+03)
      VLSO(3,10)=(-3.69062E+03,-1.24165E+02)
      VLSO(4,10)=(-5.50126E+01, 2.29030E+01)
      VLSO(5,10)=( 0.0        , 0.0        )
C
C 725 MeV DATA
      NUMDT2(11)=5
C
      RANGE2(1,11)=0.11
      RANGE2(2,11)=0.15
      RANGE2(3,11)=0.25
      RANGE2(4,11)=0.40
      RANGE2(5,11)=0.70
C
      VLSO(1,11)=( 0.0        , 0.0        )
      VLSO(2,11)=( 1.65923E+04, 5.33584E+03)
      VLSO(3,11)=(-4.53126E+03, 5.96861E+02)
      VLSO(4,11)=( 1.73517E+00,-1.13219E+01)
      VLSO(5,11)=( 0.0        , 0.0        )
C
C 800 MeV DATA
      NUMDT2(12)=5
C
      RANGE2(1,12)=0.11
      RANGE2(2,12)=0.15
      RANGE2(3,12)=0.25
      RANGE2(4,12)=0.40
      RANGE2(5,12)=0.70
C
      VLSO(1,12)=( 0.0        , 0.0        )
      VLSO(2,12)=( 2.20254E+04, 3.19857E+03)
      VLSO(3,12)=(-5.30993E+03, 1.04771E+03)
      VLSO(4,12)=( 5.53415E+01,-4.51299E+01)
      VLSO(5,12)=( 0.0        , 0.0        )
C
C 1000 MeV DATA
      NUMDT2(13)=5
C
      RANGE2(1,13)=0.11
      RANGE2(2,13)=0.15
      RANGE2(3,13)=0.25
      RANGE2(4,13)=0.40
      RANGE2(5,13)=0.70
C
      VLSO(1,13)=( 0.0        , 0.0        )
      VLSO(2,13)=( 2.72900E+04, 1.89246E+03)
      VLSO(3,13)=(-6.00841E+03, 1.31492E+03)
      VLSO(4,13)=( 1.38283E+02,-9.24643E+01)
      VLSO(5,13)=( 0.0        , 0.0        )
C
  300 CONTINUE
C
C DO LOOP OF ENERGY
      DO 350 J=NENGMN,NENGMX
C DIRECT
      VLSOD(J)=(0.0,0.0)
      DO 320 I=1,NUMDT2(J)
        VLSOD(J)=VLSOD(J)+
     &     (8.0*CPI*VLSO(I,J)*Q*(RANGE2(I,J)**5.0)
     &     /((1.0+(Q*RANGE2(I,J))**2.0)**2.0))
  320 CONTINUE
C
C EXCHANGE
      VLSOE(J)=(0.0,0.0)
      DO 330 I=1,NUMDT2(J)
        VLSOE(J)=VLSOE(J)+
     &     (8.0*CPI*VLSO(I,J)*QQ*(RANGE2(I,J)**5.0)
     &     /((1.0+(QQ*RANGE2(I,J))**2.0)**2.0))
  330 CONTINUE
  350 CONTINUE
C
C INTERPOLATION
C DIRECT
      VLSOD(0)=(0.0,0.0)
      DO 380 J=NENGMN,NENGMX
        VLSOD(0)=VLSOD(0)+VLSOD(J)*FNL(J)
  380 CONTINUE
C
C EXCHANGE
      VLSOE(0)=(0.0,0.0)
      DO 390 J=NENGMN,NENGMX
        VLSOE(0)=VLSOE(0)+VLSOE(J)*FNL(J)
  390 CONTINUE
C
C***************
C TENSOR ODD   *
C***************
C
C 50 MeV DATA
      VTNO(1,1)=( 2.68030E+03,-5.07468E+03)
      VTNO(2,1)=(-6.36557E+01, 4.66389E+02)
      VTNO(3,1)=(-5.19215E+00,-3.52030E+01)
      VTNO(4,1)=( 2.49188E+01, 2.06097E+00)
C
C 100 MeV DATA
      VTNO(1,2)=( 9.03713E+02,-8.43141E+03)
      VTNO(2,2)=( 8.09495E+01, 1.12487E+03)
      VTNO(3,2)=(-3.15586E+00,-1.55646E+02)
      VTNO(4,2)=( 2.14986E+01, 1.41551E+01)
C
C 140 MeV DATA
      VTNO(1,3)=( 1.65808E+03,-8.64691E+03)
      VTNO(2,3)=(-1.18309E+02, 1.35798E+03)
      VTNO(3,3)=( 4.66086E+01,-2.25213E+02)
      VTNO(4,3)=( 1.40732E+01, 2.33058E+01)
C
C 175 MeV DATA
      VTNO(1,4)=( 1.54653E+03,-8.33357E+03)
      VTNO(2,4)=(-1.35162E+02, 1.44887E+03)
      VTNO(3,4)=( 5.59220E+01,-2.65783E+02)
      VTNO(4,4)=( 1.17774E+01, 2.95019E+01)
C
C 210 MeV DATA
      VTNO(1,5)=( 5.09043E+04,-1.47371E+05)
      VTNO(2,5)=(-4.09914E+03, 9.39215E+03)
      VTNO(3,5)=( 3.34910E+02,-3.03689E+02)
      VTNO(4,5)=( 1.48573E+01, 3.33699E+00)
C
C 270 MeV DATA
      VTNO(1,6)=( 1.56052E+04,-1.08413E+05)
      VTNO(2,6)=(-1.09107E+03, 7.47658E+03)
      VTNO(3,6)=( 1.77657E+02,-2.84082E+02)
      VTNO(4,6)=( 0.0        , 0.0        )
      VTNO(5,6)=( 1.61522E+01, 3.72577E+00)
C
C 325 MeV DATA
      VTNO(1,7)=( 7.31966E+03,-8.38323E+04)
      VTNO(2,7)=(-3.19766E+02, 6.12059E+03)
      VTNO(3,7)=( 1.21190E+02,-2.59993E+02)
      VTNO(4,7)=( 0.0        , 0.0        )
      VTNO(5,7)=( 1.64427E+01, 3.80885E+00)
C
C 425 MeV DATA
      VTNO(1,8)=(-6.93196E+03,-5.56998E+04)
      VTNO(2,8)=( 1.15228E+03, 3.76558E+03)
      VTNO(3,8)=(-1.14221E+01,-1.49571E+02)
      VTNO(4,8)=( 0.0        , 0.0        )
      VTNO(5,8)=( 1.82445E+01, 2.03486E+00)
C
C 515 MeV DATA
      VTNO(1,9)=(-1.38326E+05,-4.84877E+05)
      VTNO(2,9)=( 2.67866E+04, 8.07924E+04)
      VTNO(3,9)=(-1.61638E+02,-1.25418E+03)
      VTNO(4,9)=( 0.0        , 0.0        )
      VTNO(5,9)=( 0.0        , 0.0        )
      VTNO(6,9)=( 1.80432E+01, 3.69280E-01)
C
C 650 MeV DATA
      VTNO(1,10)=(-4.20733E+05,-7.69279E+05)
      VTNO(2,10)=( 9.49969E+04, 1.70680E+05)
      VTNO(3,10)=(-2.34650E+03,-4.73466E+03)
      VTNO(4,10)=( 0.0        , 0.0        )
      VTNO(5,10)=( 1.83095E+01, 1.23098E+00)
C
C 725 MeV DATA
      VTNO(1,11)=(-5.17544E+05,-8.08860E+05)
      VTNO(2,11)=( 1.21805E+05, 1.87741E+05)
      VTNO(3,11)=(-3.04031E+03,-6.01944E+03)
      VTNO(4,11)=( 0.0        , 0.0        )
      VTNO(5,11)=( 1.80946E+01, 1.97737E+00)
C
C 800 MeV DATA
      VTNO(1,12)=(-5.84629E+05,-8.21321E+05)
      VTNO(2,12)=( 1.40107E+05, 1.95852E+05)
      VTNO(3,12)=(-3.32028E+03,-6.58679E+03)
      VTNO(4,12)=( 0.0        , 0.0        )
      VTNO(5,12)=( 1.78568E+01, 2.81477E+00)
C
C 1000 MeV DATA
      VTNO(1,13)=(-5.18921E+05,-3.90684E+05)
      VTNO(2,13)=( 1.33075E+05, 9.01634E+04)
      VTNO(3,13)=(-3.33354E+03,-3.81076E+03)
      VTNO(4,13)=( 0.0        , 0.0        )
      VTNO(5,13)=( 1.76171E+01, 1.82222E+00)
C
  400 CONTINUE
C
C DO LOOP OF ENERGY
      DO 450 J=NENGMN,NENGMX
C DIRECT
      VTNOD(J)=(0.0,0.0)
      DO 420 I=1,NUMDT2(J)
        VTNOD(J)=VTNOD(J)+
     &     (32.0*CPI*VTNO(I,J)*Q*Q*(RANGE2(I,J)**7.0)
     &     /((1.0+(Q*RANGE2(I,J))**2.0)**3.0))
  420 CONTINUE
C
C EXCHANGE
      VTNOE(J)=(0.0,0.0)
      DO 430 I=1,NUMDT2(J)
        VTNOE(J)=VTNOE(J)+
     &     (32.0*CPI*VTNO(I,J)*QQ*QQ*(RANGE2(I,J)**7.0)
     &     /((1.0+(QQ*RANGE2(I,J))**2.0)**3.0))
  430 CONTINUE
  450 CONTINUE
C
C INTERPOLATION
C DIRECT
      VTNOD(0)=(0.0,0.0)
      DO 480 J=NENGMN,NENGMX
        VTNOD(0)=VTNOD(0)+VTNOD(J)*FNL(J)
  480 CONTINUE
C
C EXCHANGE
      VTNOE(0)=(0.0,0.0)
      DO 490 J=NENGMN,NENGMX
        VTNOE(0)=VTNOE(0)+VTNOE(J)*FNL(J)
  490 CONTINUE
C
C***************
C SINGLET EVEN *
C***************
C
C 50 MeV DATA
      VCSE(1,1)=( 1.34417E+04,-7.38213E+02)
      VCSE(2,1)=(-3.89887E+03,-2.12695E+02)
      VCSE(3,1)=(-1.05000E+01, 0.0)
C
C 100 MeV DATA
      VCSE(1,2)=( 1.05984E+04, 6.45678E+02)
      VCSE(2,2)=(-3.21264E+03,-3.43385E+02)
      VCSE(3,2)=(-1.05000E+01, 0.0)
C
C 140 MeV DATA
      VCSE(1,3)=( 9.47399E+03, 1.12801E+03)
      VCSE(2,3)=(-2.92063E+03,-4.06183E+02)
      VCSE(3,3)=(-1.05000E+01, 0.0)
C
C 175 MeV DATA
      VCSE(1,4)=( 8.84575E+03, 1.35124E+03)
      VCSE(2,4)=(-2.74630E+03,-4.44157E+02)
      VCSE(3,4)=(-1.05000E+01, 0.0)
C
C 210 MeV DATA
      VCSE(1,5)=( 8.39519E+03, 1.45853E+03)
      VCSE(2,5)=(-2.61566E+03,-4.69589E+02)
      VCSE(3,5)=(-1.05000E+01, 0.0)
C
C 270 MeV DATA
      VCSE(1,6)=( 5.89037E+03, 2.21264E+03)
      VCSE(2,6)=(-1.36195E+03,-9.00238E+02)
      VCSE(3,6)=(-2.29750E+02, 8.59426E+01)
      VCSE(4,6)=(-1.05000E+01, 0.0)
C
C 325 MeV DATA
      VCSE(1,7)=( 5.75664E+03, 2.33238E+03)
      VCSE(2,7)=(-1.34884E+03,-1.01915E+03)
      VCSE(3,7)=(-2.16226E+02, 1.09747E+02)
      VCSE(4,7)=(-1.05000E+01, 0.0)
C
C 425 MeV DATA
      VCSE(1,8)=( 5.51214E+03, 3.49227E+03)
      VCSE(2,8)=(-1.29666E+03,-1.76395E+03)
      VCSE(3,8)=(-2.02124E+02, 2.34461E+02)
      VCSE(4,8)=(-1.05000E+01, 0.0)
C
C 515 MeV DATA
      VCSE(1,9)=( 4.11680E+03, 5.52280E+03)
      VCSE(2,9)=(-6.54160E+02,-2.95326E+03)
      VCSE(3,9)=(-2.85779E+02, 4.37528E+02)
      VCSE(4,9)=(-1.05000E+01, 0.0)
C
C 650 MeV DATA
      VCSE(1,10)=(-3.92178E+04, 2.56017E+04)
      VCSE(2,10)=( 1.99951E+04,-7.83054E+03)
      VCSE(3,10)=(-2.83362E+03,-9.47853E+01)
      VCSE(4,10)=(-1.05000E+01, 0.0)
C
C 725 MeV DATA
      VCSE(1,11)=(-4.24281E+04, 1.33343E+04)
      VCSE(2,11)=( 2.10358E+04,-3.19746E+03)
      VCSE(3,11)=(-2.82853E+03,-5.40702E+02)
      VCSE(4,11)=(-1.05000E+01, 0.0)
C
C 800 MeV DATA
      VCSE(1,12)=(-4.26964E+04, 2.85532E+03)
      VCSE(2,12)=( 2.10809E+04, 1.02443E+03)
      VCSE(3,12)=(-2.77679E+03,-9.96233E+02)
      VCSE(4,12)=(-1.05000E+01, 0.0)
C
C 1000 MeV DATA
      VCSE(1,13)=(-3.97083E+04,-1.41428E+04)
      VCSE(2,13)=( 1.98196E+04, 8.67176E+03)
      VCSE(3,13)=(-2.56051E+03,-1.99888E+03)
      VCSE(4,13)=(-1.05000E+01, 0.0)
C
  500 CONTINUE
C
C DO LOOP OF ENERGY
      DO 550 J=NENGMN,NENGMX
C DIRECT
      VSED(J)=(0.0,0.0)
      DO 520 I=1,NUMDAT(J)
        VSED(J)=VSED(J)+
     &   4.0*CPI*VCSE(I,J)*(RANGE(I,J)**3.0)/(1.0+(Q*RANGE(I,J))**2.0)
  520 CONTINUE
C
C EXCHANGE
      VSEE(J)=(0.0,0.0)
      DO 530 I=1,NUMDAT(J)
        VSEE(J)=VSEE(J)+
     &   4.0*CPI*VCSE(I,J)*(RANGE(I,J)**3.0)/(1.0+(QQ*RANGE(I,J))**2.0)
  530 CONTINUE
  550 CONTINUE
C
C INTERPOLATION
C DIRECT
      VSED(0)=(0.0,0.0)
      DO 580 J=NENGMN,NENGMX
        VSED(0)=VSED(0)+VSED(J)*FNL(J)
  580 CONTINUE
C
C EXCHANGE
      VSEE(0)=(0.0,0.0)
      DO 590 J=NENGMN,NENGMX
        VSEE(0)=VSEE(0)+VSEE(J)*FNL(J)
  590 CONTINUE
C
C***************
C TRIPLET EVEN *
C***************
C
C 50 MeV DATA
      VCTE(1,1)=( 1.77164E+04, 1.15584E+04)
      VCTE(2,1)=(-4.96816E+03,-3.87153E+03)
      VCTE(3,1)=(-1.05000E+01, 0.0)
C
C 100 MeV DATA
      VCTE(1,2)=( 8.89417E+03, 1.13187E+04)
      VCTE(2,2)=(-2.79683E+03,-3.62479E+03)
      VCTE(3,2)=(-1.05000E+01, 0.0)
C
C 140 MeV DATA
      VCTE(1,3)=( 5.95751E+03, 9.74299E+03)
      VCTE(2,3)=(-1.97848E+03,-3.13550E+03)
      VCTE(3,3)=(-1.05000E+01, 0.0)
C
C 175 MeV DATA
      VCTE(1,4)=( 4.50223E+03, 8.48148E+03)
      VCTE(2,4)=(-1.53068E+03,-2.75204E+03)
      VCTE(3,4)=(-1.05000E+01, 0.0)
C
C 210 MeV DATA
      VCTE(1,5)=( 3.56735E+03, 7.41973E+03)
      VCTE(2,5)=(-1.21675E+03,-2.43121E+03)
      VCTE(3,5)=(-1.05000E+01, 0.0)
C
C 270 MeV DATA
      VCTE(1,6)=( 3.47090E+03, 3.62968E+03)
      VCTE(2,6)=(-1.34793E+03,-6.76925E+02)
      VCTE(3,6)=( 1.04810E+02,-2.79248E+02)
      VCTE(4,6)=(-1.05000E+01, 0.0)
C
C 325 MeV DATA
      VCTE(1,7)=( 2.66532E+03, 3.03512E+03)
      VCTE(2,7)=(-1.00177E+03,-5.47907E+02)
      VCTE(3,7)=( 8.51226E+01,-2.56626E+02)
      VCTE(4,7)=(-1.05000E+01, 0.0)
C
C 425 MeV DATA
      VCTE(1,8)=( 1.40919E+03, 2.02774E+03)
      VCTE(2,8)=(-3.64823E+02,-2.63465E+02)
      VCTE(3,8)=( 1.21137E+01,-2.51687E+02)
      VCTE(4,8)=(-1.05000E+01, 0.0)
C
C 515 MeV DATA
      VCTE(1,9)=( 5.20997E+02, 1.33119E+03)
      VCTE(2,9)=( 1.32111E+02,-4.76319E+01)
      VCTE(3,9)=(-5.91971E+01,-2.59686E+02)
      VCTE(4,9)=(-1.05000E+01, 0.0)
C
C 650 MeV DATA
      VCTE(1,10)=(-1.13960E+04,-1.79489E+04)
      VCTE(2,10)=( 5.12998E+03, 9.73318E+03)
      VCTE(3,10)=(-3.99120E+02,-1.75896E+03)
      VCTE(4,10)=(-1.05000E+01, 0.0)
C
C 725 MeV DATA
      VCTE(1,11)=(-1.16186E+04,-1.75304E+04)
      VCTE(2,11)=( 5.08507E+03, 9.50388E+03)
      VCTE(3,11)=(-3.23352E+02,-1.73338E+03)
      VCTE(4,11)=(-1.05000E+01, 0.0)
C
C 800 MeV DATA
      VCTE(1,12)=(-1.16195E+04,-1.61642E+04)
      VCTE(2,12)=( 4.96225E+03, 8.88072E+03)
      VCTE(3,12)=(-2.46893E+02,-1.66554E+03)
      VCTE(4,12)=(-1.05000E+01, 0.0)
C
C 1000 MeV DATA
      VCTE(1,13)=(-1.30391E+04,-1.10215E+04)
      VCTE(2,13)=( 5.44155E+03, 6.49075E+03)
      VCTE(3,13)=(-1.99668E+02,-1.38744E+03)
      VCTE(4,13)=(-1.05000E+01, 0.0)
C
  600 CONTINUE
C
C DO LOOP OF ENERGY
      DO 650 J=NENGMN,NENGMX
C DIRECT
      VTED(J)=(0.0,0.0)
      DO 620 I=1,NUMDAT(J)
        VTED(J)=VTED(J)+
     &   4.0*CPI*VCTE(I,J)*(RANGE(I,J)**3.0)/(1.0+(Q*RANGE(I,J))**2.0)
  620 CONTINUE
C
C EXCHANGE
      VTEE(J)=(0.0,0.0)
      DO 630 I=1,NUMDAT(J)
        VTEE(J)=VTEE(J)+
     &   4.0*CPI*VCTE(I,J)*(RANGE(I,J)**3.0)/(1.0+(QQ*RANGE(I,J))**2.0)
  630 CONTINUE
  650 CONTINUE
C
C INTERPOLATION
C DIRECT
      VTED(0)=(0.0,0.0)
      DO 680 J=NENGMN,NENGMX
        VTED(0)=VTED(0)+VTED(J)*FNL(J)
  680 CONTINUE
C
C EXCHANGE
      VTEE(0)=(0.0,0.0)
      DO 690 J=NENGMN,NENGMX
        VTEE(0)=VTEE(0)+VTEE(J)*FNL(J)
  690 CONTINUE
C
C***************
C LS EVEN      *
C***************
C
C 50 MeV DATA
      VLSE(1,1)=(-2.19622E+04,-8.84002E+04)
      VLSE(2,1)=(-1.01819E+03, 5.54246E+03)
      VLSE(3,1)=( 0.0        , 0.0        )
      VLSE(4,1)=( 0.0        , 0.0        )
C
C 100 MeV DATA
      VLSE(1,2)=(-1.14015E+04,-1.95620E+04)
      VLSE(2,2)=(-5.97390E+02, 2.18728E+03)
      VLSE(3,2)=( 0.0        , 0.0        )
      VLSE(4,2)=( 0.0        , 0.0        )
C
C 140 MeV DATA
      VLSE(1,3)=(-7.54122E+03,-7.25238E+03)
      VLSE(2,3)=(-4.64320E+02, 1.31936E+03)
      VLSE(3,3)=( 0.0        , 0.0        )
      VLSE(4,3)=( 0.0        , 0.0        )
C
C 175 MeV DATA
      VLSE(1,4)=(-5.54835E+03,-3.33593E+03)
      VLSE(2,4)=(-3.98098E+02, 9.43863E+02)
      VLSE(3,4)=( 0.0        , 0.0        )
      VLSE(4,4)=( 0.0        , 0.0        )
C
C 210 MeV DATA
      VLSE(1,5)=( 0.0        , 0.0        )
      VLSE(2,5)=(-4.27719E+03,-1.59970E+03)
      VLSE(3,5)=(-3.51873E+02, 7.22578E+02)
      VLSE(4,5)=( 0.0        , 0.0        )
C
C 270 MeV DATA
      VLSE(1,6)=( 0.0        , 0.0        )
      VLSE(2,6)=(-6.99955E+03,-8.07467E+02)
      VLSE(3,6)=( 3.49040E+02, 5.59786E+02)
      VLSE(4,6)=(-6.89521E+01,-4.87654E+00)
      VLSE(5,6)=( 0.0        , 0.0        )
C
C 325 MeV DATA
      VLSE(1,7)=( 0.0        , 0.0        )
      VLSE(2,7)=(-4.70787E+03,-5.45600E+02)
      VLSE(3,7)=( 1.78549E+02, 4.88696E+02)
      VLSE(4,7)=(-5.35770E+01,-1.10717E+01)
      VLSE(5,7)=( 0.0        , 0.0        )
C
C 425 MeV DATA
      VLSE(1,8)=( 0.0        , 0.0        )
      VLSE(2,8)=(-2.77581E+03,-3.82611E+02)
      VLSE(3,8)=( 2.95274E+01, 4.10099E+02)
      VLSE(4,8)=(-3.48021E+01,-1.73962E+01)
      VLSE(5,8)=( 0.0        , 0.0        )
C
C 515 MeV DATA
      VLSE(1,9)=( 0.0        , 0.0        )
      VLSE(2,9)=( 0.0        , 0.0        )
      VLSE(3,9)=(-1.86850E+03,-2.29441E+02)
      VLSE(4,9)=(-5.89149E+01, 3.54667E+02)
      VLSE(5,9)=(-2.09289E+01,-1.95960E+01)
      VLSE(6,9)=( 0.0        , 0.0        )
C
C 650 MeV DATA
      VLSE(1,10)=( 0.0        , 0.0        )
      VLSE(2,10)=(-1.04085E+04,-2.51057E+04)
      VLSE(3,10)=( 5.99248E+01, 3.03330E+03)
      VLSE(4,10)=(-2.22963E+02, 5.47808E+01)
      VLSE(5,10)=( 0.0        , 0.0        )
C
C 725 MeV DATA
      VLSE(1,11)=( 0.0        , 0.0        )
      VLSE(2,11)=(-2.46625E+02,-2.12765E+04)
      VLSE(3,11)=(-8.89280E+02, 2.83036E+03)
      VLSE(4,11)=(-1.70052E+02, 3.79015E+01)
      VLSE(5,11)=( 0.0        , 0.0        )
C
C 800 MeV DATA
      VLSE(1,12)=( 0.0        , 0.0        )
      VLSE(2,12)=( 6.21487E+03,-1.72013E+04)
      VLSE(3,12)=(-1.56493E+03, 2.56370E+03)
      VLSE(4,12)=(-1.26589E+02, 2.71088E+01)
      VLSE(5,12)=( 0.0        , 0.0        )
C
C 1000 MeV DATA
      VLSE(1,13)=( 0.0        , 0.0        )
      VLSE(2,13)=( 1.25797E+04,-7.66320E+03)
      VLSE(3,13)=(-2.41149E+03, 1.79314E+03)
      VLSE(4,13)=(-4.58047E+01, 1.57346E+01)
      VLSE(5,13)=( 0.0        , 0.0        )
C
  700 CONTINUE
C
C DO LOOP OF ENERGY
      DO 750 J=NENGMN,NENGMX
C DIRECT
      VLSED(J)=(0.0,0.0)
      DO 720 I=1,NUMDT2(J)
        VLSED(J)=VLSED(J)+
     &     (8.0*CPI*VLSE(I,J)*Q*(RANGE2(I,J)**5.0)
     &     /((1.0+(Q*RANGE2(I,J))**2.0)**2.0))
  720 CONTINUE
C
C EXCHANGE
      VLSEE(J)=(0.0,0.0)
      DO 730 I=1,NUMDT2(J)
        VLSEE(J)=VLSEE(J)+
     &     (8.0*CPI*VLSE(I,J)*QQ*(RANGE2(I,J)**5.0)
     &     /((1.0+(QQ*RANGE2(I,J))**2.0)**2.0))
  730 CONTINUE
  750 CONTINUE
C
C INTERPOLATION
C DIRECT
      VLSED(0)=(0.0,0.0)
      DO 780 J=NENGMN,NENGMX
        VLSED(0)=VLSED(0)+VLSED(J)*FNL(J)
  780 CONTINUE
C
C EXCHANGE
      VLSEE(0)=(0.0,0.0)
      DO 790 J=NENGMN,NENGMX
        VLSEE(0)=VLSEE(0)+VLSEE(J)*FNL(J)
  790 CONTINUE
C
C***************
C TENSOR EVEN  *
C***************
C
C 50 MeV DATA
      VTNE(1,1)=( 1.71786E+05, 1.72442E+04)
      VTNE(2,1)=(-1.88801E+04,-1.67281E+03)
      VTNE(3,1)=( 2.44410E+03, 1.31469E+02)
      VTNE(4,1)=(-2.80717E+02,-6.16547E+00)
C
C 100 MeV DATA
      VTNE(1,2)=( 6.89650E+04, 1.72934E+04)
      VTNE(2,2)=(-1.02174E+04,-2.55965E+03)
      VTNE(3,2)=( 1.64327E+03, 3.49963E+02)
      VTNE(4,2)=(-2.32416E+02,-3.03573E+01)
C
C 140 MeV DATA
      VTNE(1,3)=( 3.84343E+04, 1.39275E+04)
      VTNE(2,3)=(-6.94577E+03,-2.54752E+03)
      VTNE(3,3)=( 1.25503E+03, 4.22819E+02)
      VTNE(4,3)=(-2.02390E+02,-4.27937E+01)
C
C 175 MeV DATA
      VTNE(1,4)=( 2.35229E+04, 1.12392E+04)
      VTNE(2,4)=(-4.96930E+03,-2.34963E+03)
      VTNE(3,4)=( 9.60072E+02, 4.35747E+02)
      VTNE(4,4)=(-1.74041E+02,-4.78589E+01)
C
C 210 MeV DATA
      VTNE(1,5)=( 3.25631E+05, 2.12453E+05)
      VTNE(2,5)=(-2.47288E+04,-1.58050E+04)
      VTNE(3,5)=( 6.54904E+02, 4.78422E+02)
      VTNE(4,5)=(-6.97061E+01,-4.70474E+00)
C
C 270 MeV DATA
      VTNE(1,6)=( 8.05275E+04, 1.27002E+05)
      VTNE(2,6)=(-7.43299E+03,-1.04694E+04)
      VTNE(3,6)=(-2.95714E+01, 3.85365E+02)
      VTNE(4,6)=( 0.0        , 0.0        )
      VTNE(5,6)=(-6.02151E+01,-4.85957E+00)
C
C 325 MeV DATA
      VTNE(1,7)=(-6.10415E+03, 7.84640E+04)
      VTNE(2,7)=(-3.59561E+02,-6.66960E+03)
      VTNE(3,7)=(-3.71369E+02, 2.78689E+02)
      VTNE(4,7)=( 0.0        , 0.0        )
      VTNE(5,7)=(-5.39899E+01,-4.21445E+00)
C
C 425 MeV DATA
      VTNE(1,8)=(-3.01782E+04, 3.69347E+04)
      VTNE(2,8)=( 1.27983E+03,-1.80084E+03)
      VTNE(3,8)=(-4.48751E+02, 4.40981E+01)
      VTNE(4,8)=( 0.0        , 0.0        )
      VTNE(5,8)=(-5.11201E+01,-6.54421E-01)
C
C 515 MeV DATA
      VTNE(1,9)=(-1.96083E+06,-2.03086E+05)
      VTNE(2,9)=( 4.44801E+05, 6.98780E+04)
      VTNE(3,9)=(-1.31909E+04,-1.26088E+03)
      VTNE(4,9)=( 0.0        , 0.0        )
      VTNE(5,9)=( 0.0        , 0.0        )
      VTNE(6,9)=(-5.45907E+01,-4.88106E-02)
C
C 650 MeV DATA
      VTNE(1,10)=(-1.93088E+06,-4.38855E+05)
      VTNE(2,10)=( 4.51725E+05, 1.31117E+05)
      VTNE(3,10)=(-1.37286E+04,-2.51054E+03)
      VTNE(4,10)=( 0.0        , 0.0        )
      VTNE(5,10)=(-5.20253E+01, 3.97620E-01)
C
C 725 MeV DATA
      VTNE(1,11)=(-1.85765E+06,-4.83693E+05)
      VTNE(2,11)=( 4.40270E+05, 1.48528E+05)
      VTNE(3,11)=(-1.35780E+04,-3.12498E+03)
      VTNE(4,11)=( 0.0        , 0.0        )
      VTNE(5,11)=(-5.07714E+01, 7.42336E-01)
C
C 800 MeV DATA
      VTNE(1,12)=(-1.74354E+06,-4.31198E+05)
      VTNE(2,12)=( 4.19542E+05, 1.44384E+05)
      VTNE(3,12)=(-1.32187E+04,-3.35644E+03)
      VTNE(4,12)=( 0.0        , 0.0        )
      VTNE(5,12)=(-4.96724E+01, 1.08216E+00)
C
C 1000 MeV DATA
      VTNE(1,13)=(-1.73721E+06,-3.12921E+05)
      VTNE(2,13)=( 4.34929E+05, 1.20438E+05)
      VTNE(3,13)=(-1.39942E+04,-3.11610E+03)
      VTNE(4,13)=( 0.0        , 0.0        )
      VTNE(5,13)=(-4.57834E+01, 1.36250E+00)
C
  800 CONTINUE
C
C DO LOOP OF ENERGY
      DO 850 J=NENGMN,NENGMX
C DIRECT
      VTNED(J)=(0.0,0.0)
      DO 820 I=1,NUMDT2(J)
        VTNED(J)=VTNED(J)+
     &     (32.0*CPI*VTNE(I,J)*Q*Q*(RANGE2(I,J)**7.0)
     &     /((1.0+(Q*RANGE2(I,J))**2.0)**3.0))
  820 CONTINUE
C
C EXCHANGE
      VTNEE(J)=(0.0,0.0)
      DO 830 I=1,NUMDT2(J)
        VTNEE(J)=VTNEE(J)+
     &     (32.0*CPI*VTNE(I,J)*QQ*QQ*(RANGE2(I,J)**7.0)
     &     /((1.0+(QQ*RANGE2(I,J))**2.0)**3.0))
  830 CONTINUE
  850 CONTINUE
C
C INTERPOLATION
C DIRECT
      VTNED(0)=(0.0,0.0)
      DO 880 J=NENGMN,NENGMX
        VTNED(0)=VTNED(0)+VTNED(J)*FNL(J)
  880 CONTINUE
C
C EXCHANGE
      VTNEE(0)=(0.0,0.0)
      DO 890 J=NENGMN,NENGMX
        VTNEE(0)=VTNEE(0)+VTNEE(J)*FNL(J)
  890 CONTINUE
C
C TRANSITION AMPLITUDE
C A0,A1,...,F1 MULTIPLIED BY ETA
      TAMPFL(1)=( VSOD(0)+9.0*VTOD(0)+3.0*VSED(0)+3.0*VTED(0))/16.0
     &          +(-VSOE(0)-9.0*VTOE(0)+3.0*VSEE(0)+3.0*VTEE(0))/16.0
      TAMPFL(2)=(-VSOD(0)+3.0*VTOD(0)+1.0*VSED(0)-3.0*VTED(0))/16.0
     &          +( VSOE(0)-3.0*VTOE(0)+1.0*VSEE(0)-3.0*VTEE(0))/16.0
      TAMPFL(3)=(-VSOD(0)+3.0*VTOD(0)-3.0*VSED(0)+1.0*VTED(0))/16.0
     &          +( VSOE(0)-3.0*VTOE(0)-3.0*VSEE(0)+1.0*VTEE(0))/16.0
     &      +(-3.0*(-VTNOD(0))-(-VTNED(0))-3.0*VTNOE(0)-(-VTNEE(0)))/4.0
      TAMPFL(4)=( VSOD(0)+1.0*VTOD(0)-1.0*VSED(0)-1.0*VTED(0))/16.0
     &          +(-VSOE(0)-1.0*VTOE(0)-1.0*VSEE(0)-1.0*VTEE(0))/16.0
     &      +(-1.0*(-VTNOD(0))+(-VTNED(0))-1.0*VTNOE(0)+(-VTNEE(0)))/4.0
      TAMPFL(5)=-(3.0*QQ*VLSOD(0)+QQ*VLSED(0))/16.0
     &           -(3.0*Q *VLSOE(0)-Q *VLSEE(0))/16.0
      TAMPFL(6)=-(1.0*QQ*VLSOD(0)-QQ*VLSED(0))/16.0
     &           -(1.0*Q *VLSOE(0)+Q *VLSEE(0))/16.0
      TAMPFL(7)=TAMPFL(3)+(9.0*(-VTNOD(0))+3.0*(-VTNED(0)))/4.0
      TAMPFL(8)=TAMPFL(4)+(3.0*(-VTNOD(0))-3.0*(-VTNED(0)))/4.0
      TAMPFL(9)=TAMPFL(3)+(9.0*  VTNOE(0) +3.0*(-VTNEE(0)))/4.0
      TAMPFL(10)=TAMPFL(4)+(3.0*  VTNOE(0) -3.0*(-VTNEE(0)))/4.0
C
      DO 1000 NCHNL=1,10
         TAMPFL(NCHNL)=FACMOD*TAMPFL(NCHNL)
 1000 CONTINUE
C
      RETURN
      END
