c----------------------------------------------------------------------
      subroutine   nrelopt(ich,Atg,nrmax,drho1,zzz,fkay1,
     &                     eta0,tcm,rhobc1,tautau)
c     generate the non-relativistic optical potentials
c---------------------------------------------------------------------
C  INPUT from argument
C    ich    : =1: incident channel =2: exit channel 
C    nrmax  : Maximum no. of radial mesh points 
C    Atg    : A_{tg}
C    drho1  : k*dr
C    zzz    : Z_{prj}*Z_{tg} for ich=1;  Z_{ejc}*Z_{rs} for ich=2
C    fkay1  : k in c.m
C    eta0   : Coulomb paremeter
C    tcm    : Kinetic energy in c.m. 
C    rhobc1 : k*R_{tg}
C    tautau : t_{z}*T_{z}
C  INPUT from   common/stdopt/ 
C    vd1(ich)  : V Depth of real potential
C    wd1(ich)  : W Depth of imaginary potential
C    vsod1(ich): V_{sl} Depth of spin-orbit real potential
C    wsod(ich) : W_{sl} Depth of spin-orbit imaginary potential
C    rrd1(ich) : r_r radius parameter of real potential
C    ard1(ich) : a_r diffuseness parameter of real potential
C    rid1(ich) : r_i radius parameter of imaginary potential
C    aid1(ich) : a_i diffuseness parameter of imaginary potential
C    csdgd(ich): Surface imaginary potential type and strength specification
C                C_s if r_g=0, or C_g if r_g .ne. 0 
C    rsord(ich): r_{sl,r} radius parameter of spin-orbit real potential
C    asord(ich): a_{sl,r} diffuseness parameter of spin-orbit real potential
C    rsoid(ich): r_{sl,i} radius parameter of spin-orbit imaginary potential
C    asoid(ich): a_{sl,i} diffuseness parameter of spin-orbit imaginary potential
C    ktop(ich) : imaginary potential type option
C               =1 volume; =2, Volume+surface Gauss; =3 volume+ W-S derivative
C    rgd(ich)  : r_g Radius parameter of Gauss type surface imaginary pot.
C    agd(ich)  : a_g Diffuseness parameterof Gauss type surface imaginary pot  
C    ktisp(ich): Option for isospin dependent (Lane) potential. 2 digits value
C              : ktisr=the first digit, ktisi = the second digit
C              : ktisr=0 No real pot.     ; ktisi=0 No imaginary pot.
C              :      =1 Volume real pot. ; ktisi=1 Volume imaginary pot.
C              :      =1 Surface real pot.; ktisi=1 Surface imaginary pot.
C    visd(ich) : V_{is} Depth of Lane pot.(real) 
C    wisd(ich) : W_{is} Depth of Lane pot.(imaginary) 
C    risrd(ich): r_{is,r} radius parameter of Lane pot.(real) 
C    aisrd(ich): a_{is,r} diffuseness parameter of Lane pot.(real) 
C    risid(ich): r_{is,i} radius parameter of Lane pot.(imaginary)
C    aisid(ich): a_{is,i} diffuseness parameter of Lane pot.(imainary)
C  OUTPUT to common/modpot/
c    (vbcd1(nr,ich),wbcd1(nr,ich)) = (1.0 - U_{cent}/E)
c    (vsov1(nr,ich),wsov(nr,ich))  = -U_{so}/E
c------- ---------------------------------------------------------------
      include 'dimn.fh'
      include 'stdpot.fh'
      include 'modpot.fh'
c
      csd1=csdgd(ich)
      t2=fkay1*Atg**0.3333333
      rhobn1=rrd1(ich)*t2
      rhoin1=rid1(ich)*t2
      rhosr1=rsord(ich)*t2
      rhosoi=rsoid(ich)*t2
      rhoisr=risrd(ich)*t2
      rhoisi=risid(ich)*t2
      rhobng=rgd(ich)*t2
C     
      fkaar1=ard1(ich)*fkay1
      fkaai1=aid1(ich)*fkay1
      fkasr1=asord(ich)*fkay1
      fkasoi=asoid(ich)*fkay1
      fkaisr=aisrd(ich)*fkay1
      fkaisi=aisid(ich)*fkay1
      fkaybg=agd(ich)*fkay1
      vbe1=vd1(ich)/tcm
      wbe1=wd1(ich)/tcm
      vsoe1=vsod1(ich)/tcm
      wsoe=wsod(ich)/tcm
      vise=visd(ich)/tcm
      wise=wisd(ich)/tcm
c
      rho=drho1
      rho2=rho*rho
      rhobc2=rhobc1*rhobc1
      etabc=eta0/rhobc1
c
      fkay4=fkay1*fkay1*4.0
      ffisr=0.0
      ffisi=0.0
      ktisr=ktisp(ich)/10
      ktisi=ktisp(ich)-ktisr*10
      do  300  nr=1,nrmax+3
         vsov1(nr,ich)=0.0
         wsov(nr,ich)=0.0
         xr=(rho-rhobn1)/fkaar1
         exr=exp(xr)
         sr1=1.0/(1.0+exr)
         ffcr=vbe1*sr1
c      iiiiiiiiii
         xi=(rho-rhoin1)/fkaai1
         exi=exp(xi)
         si1=1.0/(1.0+exi)
         if(ktop(ich).lt.2) then
            ffci=wbe1*si1
         else if(ktop(ich).eq.2) then
            sig=exp(-((rho-rhobng)/fkaybg)**2)
            ffci=wbe1*((1.0-csd1)*si1+csd1*sig)
         else
            si2=si1*si1*exi*4.0
            ffci=wbe1*((1.0-csd1)*si1+csd1*si2)
         end if
c     ccccccccc
         if(zzz.ge.1.0) then
            if(rho.le.rhobc1) then
               ffcl=etabc*(3.0-rho2/rhobc2)
            else
               ffcl=2.0*eta0/rho
            end if
         else
            ffcl=0.0
         end if
c     so*so*so*so
         if(abs(vsoe1).ge.0.0001) then
            xsor=(rho-rhosr1)/fkasr1
            esor=exp(xsor)
            ssor1=1.0/(1.0+esor)
            ssor2=ssor1*ssor1*esor
            vsov1(nr,ich)=ssor2*fkay4/(fkasr1*rho)*vsoe1
         end if
         if(abs(wsoe).ge.0.0001) then
            xsoi=(rho-rhosoi)/fkasoi
            esoi=exp(xsoi)
            ssoi1=1.0/(1.0+esoi)
            ssoi2=ssoi1*ssoi1*esoi
            wsov(nr,ich)=ssoi2*fkay4/(fkasoi*rho)*wsoe
         end if
c   is*is*is*is
         if(ktisr.ne.0) then
            xisr=(rho-rhoisr)/fkaisr
            eisr=exp(xisr)
            sisr1=1.0/(1.0+eisr)
            if(ktisr.eq.1) then
               ffisr=vise*sisr1
            else if(ktisr.eq.2) then
               sisr2=sisr1*sisr1*eisr
               ffisr=vise*sisr2*rhoisr/fkaisr
            end if
         end if
         if(ktisi.ne.0) then
            xisi=(rho-rhoisi)/fkaisi
            eisi=exp(xisi)
            sisi1=1.0/(1.0+eisi)
            if(ktisi.eq.1) then
               ffisi=wise*sisi1
            else if(ktisi.eq.2) then
               sisi2=sisi1*sisi1*eisi
               ffisi=wise*sisi2*rhoisi/fkaisi
            end if
         end if
c     total
         vbcd1(nr,ich)=1.0-ffcl+ffcr+ffisr*tautau
         wbcd1(nr,ich)=ffci+ffisi*tautau
c
         rho=rho+drho1
         rho2=rho*rho
 300  continue
c
      return
      end
