c-----------------------------------------------------------------------
      subroutine vdrll(ltrmx,fmoel)
c-----------------------------------------------------------------------
c  calculate the driving force in cordinate representation from NN t-matrix
c  Latest update M.I. 2013.8.26
c----------------------------------------------------------------------
c   INPUT
c    ltrmx : maximum transferred l+1                from arguments
c    fmoel : Moeler factor for the optimal frame    from arguments
c    nkmax : Maximum number of momentum mesh points from fund1.fh 
c    nsrmax: number of mesh points for r            from fund1.fh
c    dsr   : mesh size of r                         from fund1.fh
c    fkdmsh(nkdm): Table of momenta for Fourier transform from lgbs.fh
c    fkdwgt(nkdm): Table of weights for Fourier transform from lgbs.fh:
c    bsl(nkdm,nsrdm,nbsldm): Table of spherical Bessel function from lgbs.fh
c    qmsh(0:nspl): Table of momenta of given NN amplitude from ampcoef.fh
c    nspl  : Number of angles of the given NN amplitude-1 (=36) from ampcoef.fh  
c    ampqa(0:nspl,5): NN amplitude data for spline from ampcoef.fh
c    ampqb(0:nspl,5): NN amplitude data for spline from ampcoef.fh
c    ampqc(0:nspl,5): NN amplitude data for spline from ampcoef.fh
c    ampqd(0:nspl,5): NN amplitude data for spline from ampcoef.fh
c
c   OUTPUT to drive.fh
c    vll(nsrdm,nsrdm,0:nbsldm,2,5): Table of the driving force to drive.fh
c       v(r1,r2,l1,nl2,i);nl2=1 -> l2=l1, nl2=2 ->l2=l1+2 
c    UNIT
c      amp : MeV*fm**3
c      vll : MeV
c---------------------------------------------------------------------
      include 'dimn.fh'
      include 'fund1.fh'
      include 'drive.fh'
      include 'lgbs.fh'
      include 'ampcoef.fh'
      complex amp(360,5),sum(5),spcp
c
      real*8 hc/197.326968d0/
      real*8 cpi/3.141592654d0/
c 
c  On-shell condition check with respect to the momentum transfer 
      if(fkdmsh(nkmax).gt.qmsh(nspl)) then
         write(6,*) 'nkmax=',nkmax
         write(6,*) 'error: qmax exceeds spline limit. qmax=',
     1        fkdmsh(nkmax),' limit=',qmsh(nspl)
        stop
      end if
c
c  Calculate NN t-matrix amplitudes in q-representation by spline
      fac=(2.0/cpi*hc)*fmoel
      do 25 k=1,nkmax
         q=fkdmsh(k)
        do 10 i=1,5
         amp(k,i)=spcp((nspl+1),q,qmsh,ampqa(0,i),ampqb(0,i),
     1                               ampqc(0,i),ampqd(0,i))*fac
   10   continue
   25 continue
c
c  Bessel transform
c
      do 300 lk1=1,ltrmx
        do 200 nlk2=1,2
          lk2=lk1+2*(nlk2-1)
          r1=0.0
          do 150 n1=1,nsrmax
            r1=r1+dsr
            n2min=1
            if(lk1.eq.lk2) n2min=n1
            r2=dsr*float(n2min-1)
c
            do 100 n2=n2min,nsrmax
              r2=r2+dsr
c
              do 70 nnn=1,5
   70         sum(nnn)=(0.0,0.0)
c
              do 90 k=1,nkmax
                sk=fkdmsh(k)
                wk=sk*sk*fkdwgt(k)*bsl(k,n1,lk1)*bsl(k,n2,lk2)
                do 80 nnn=1,5
   80             sum(nnn)=sum(nnn)+wk*amp(k,nnn)
   90         continue
c
              do 95 nnn=1,5
                vll(n1,n2,lk1,nlk2,nnn)=sum(nnn)
                if(lk1.eq.lk2) vll(n2,n1,lk1,nlk2,nnn)=sum(nnn)
   95         continue
  100       continue
  150     continue
  200   continue
  300 continue
c
      do  nnn=1,5
       do  nlk2 = 1,2
        do  n2 = 1, nsrmax
         do  n1 = 1,nsrmax
              vll(n1,n2,0,nlk2,nnn)= 0.0
         end do
        end do
       end do
      end do
c
      return
      end
